<?php
namespace ElementaryAddons\Utils;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly



class EAFREE_Controls_Groups{

	public static function get_button_style_controls( $obj, $prefix, $targets = array() ){

		$single_sel_targets = ( is_array( $targets ) && count( $targets ) > 1 ) ? implode( ', ', $targets ) : $targets[0];

		$obj->start_controls_tabs( $prefix . '_styles' );

    $obj->start_controls_tab(
      $prefix . '_normal',
      [
        'label' => esc_html__( 'Normal', 'elementary-addons' ),
      ]
    );

    $obj->add_control(
      $prefix . '_color',
      [
        'label'  => esc_html__( 'Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          $single_sel_targets => 'color: {{VALUE}}; fill: {{VALUE}};',
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'label' => esc_html__( 'Typography', 'elementary-addons' ),
        'name' => $prefix . '_typography',
        'selector' => $single_sel_targets,
        'global' => [
          'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => $prefix . '_text_shadow',
        'selector' => $single_sel_targets,
      ]
    );



    $obj->add_responsive_control(
      $prefix . '_padding',
      [
        'label' => esc_html__( 'Padding', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          $single_sel_targets => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $obj->add_responsive_control(
      $prefix . '_margin',
      [
        'label' => esc_html__( 'Margin', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          $single_sel_targets => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Border::get_type(),
      [
        'label' => esc_html__( 'Border', 'elementary-addons' ),
        'name' => $prefix . '_border',
        'selector' => $single_sel_targets,
        'fields_options' => [
          'color' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $obj->add_control(
      $prefix . '_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          $single_sel_targets => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => $prefix . '_background',
        'types' => [ 'classic', 'gradient' ],
        'selector' => $single_sel_targets,
        'fields_options' => [
          'background' => [
            'default' => '',
          ],
          'color' => [
            'dynamic' => [],
          ],
          'color_b' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => $prefix . '_shadow',
        'selector' => $single_sel_targets,
      ]
    );

    $obj->end_controls_tab();


		if( is_array( $targets ) && count( $targets ) > 0 ){
			for ( $i = 0; $i < count( $targets ); $i++ ) {
				$targets[$i] .= ':hover';
			}
		}
		$single_sel_targets_hover = ( is_array( $targets ) && count( $targets ) > 1 ) ? implode( ', ', $targets ) : $targets[0] . ':hover';

    $obj->start_controls_tab(
      $prefix . '_hover',
      [
        'label' => esc_html__( 'Hover', 'elementary-addons' ),
      ]
    );

    $obj->add_control(
      $prefix . '_color_hover',
      [
        'label'  => esc_html__( 'Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          $single_sel_targets_hover => 'color: {{VALUE}}',
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'label' => esc_html__( 'Typography', 'elementary-addons' ),
        'name' => $prefix . '_typography_hover',
        'selector' => $single_sel_targets_hover,
        'global' => [
          'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => $prefix . '_shadow_hover',
        'selector' => $single_sel_targets_hover,
      ]
    );



    $obj->add_responsive_control(
      $prefix . '_padding_hover',
      [
        'label' => esc_html__( 'Padding', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          $single_sel_targets_hover => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $obj->add_responsive_control(
      $prefix . '_margin_hover',
      [
        'label' => esc_html__( 'Margin', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          $single_sel_targets_hover => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Border::get_type(),
      [
        'label' => esc_html__( 'Border', 'elementary-addons' ),
        'name' => $prefix . '_border_hover',
        'selector' => $single_sel_targets_hover,
        'fields_options' => [
          'color' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $obj->add_control(
      $prefix . '_radius_hover',
      [
        'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          $single_sel_targets_hover => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => $prefix . '_background_hover',
        'types' => [ 'classic', 'gradient' ],
        'selector' => $single_sel_targets_hover,
        'fields_options' => [
          'background' => [
            'default' => '',
          ],
          'color' => [
            'dynamic' => [],
          ],
          'color_b' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => $prefix . '_shadow_hover',
        'selector' => $single_sel_targets_hover,
      ]
    );

    $obj->end_controls_tab();
    $obj->end_controls_tabs();

    $obj->add_control(
      $prefix . '_transition_time',
      [
        'label'   => esc_html__( 'Transition Time', 'elementary-addons' ),
        'type'    => Controls_Manager::NUMBER,
        'default' => 0.5,
        'step' => 0.1,
        'selectors' => [
          $single_sel_targets => 'transition:all {{VALUE}}s;',
        ],
        // 'separator' => 'before',
      ]
    );
	} // button Controls


	///////////////////////////// BUTTON 3 CONTROLS /////////////////////////////
	public static function get_button3_style_controls( $obj, $prefix, $targets_active = array(), $targets_normal = array(), $targets_hover = array() ){

		$active_targ = ( is_array( $targets_active ) && count( $targets_active ) > 1 ) ? implode( ', ', $targets_active ) : $targets_active[0];
		$normal_targ = ( is_array( $targets_normal ) && count( $targets_normal ) > 1 ) ? implode( ', ', $targets_normal ) : $targets_normal[0];
		$hover_targ = ( is_array( $targets_hover ) && count( $targets_hover ) > 1 ) ? implode( ', ', $targets_hover ) : $targets_hover[0];

		$obj->start_controls_tabs( $prefix . '_styles' );

		$obj->start_controls_tab(
			$prefix . '_active',
			[
				'label' => esc_html__( 'Active', 'elementary-addons' ),
			]
		);

		$obj->add_control(
			$prefix . '_active_color',
			[
				'label'  => esc_html__( 'Color', 'elementary-addons' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					$active_targ => 'color: {{VALUE}}; fill: {{VALUE}};',
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'elementary-addons' ),
				'name' => $prefix . '_active_typography',
				'selector' => $active_targ,
				'global' => [
					'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => $prefix . '_active_text_shadow',
				'selector' => $active_targ,
			]
		);



		$obj->add_responsive_control(
			$prefix . '_active_padding',
			[
				'label' => esc_html__( 'Padding', 'elementary-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					$active_targ => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
			]
		);

		$obj->add_responsive_control(
			$prefix . '_active_margin',
			[
				'label' => esc_html__( 'Margin', 'elementary-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					$active_targ => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Border::get_type(),
			[
				'label' => esc_html__( 'Border', 'elementary-addons' ),
				'name' => $prefix . '_active_border',
				'selector' => $active_targ,
				'fields_options' => [
					'color' => [
						'dynamic' => [],
					],
				],
			]
		);

		$obj->add_control(
			$prefix . '_active_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					$active_targ => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => $prefix . '_active_background',
				'types' => [ 'classic', 'gradient' ],
				'selector' => $active_targ,
				'fields_options' => [
					'background' => [
						'default' => '',
					],
					'color' => [
						'dynamic' => [],
					],
					'color_b' => [
						'dynamic' => [],
					],
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => $prefix . '_active_shadow',
				'selector' => $active_targ,
			]
		);

		$obj->end_controls_tab();

		$obj->start_controls_tab(
			$prefix . '_normal',
			[
				'label' => esc_html__( 'Normal', 'elementary-addons' ),
			]
		);

		$obj->add_control(
			$prefix . '_color',
			[
				'label'  => esc_html__( 'Color', 'elementary-addons' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					$normal_targ => 'color: {{VALUE}}; fill: {{VALUE}};',
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'elementary-addons' ),
				'name' => $prefix . '_typography',
				'selector' => $normal_targ,
				'global' => [
					'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => $prefix . '_text_shadow',
				'selector' => $normal_targ,
			]
		);



		$obj->add_responsive_control(
			$prefix . '_padding',
			[
				'label' => esc_html__( 'Padding', 'elementary-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					$normal_targ => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
			]
		);

		$obj->add_responsive_control(
			$prefix . '_margin',
			[
				'label' => esc_html__( 'Margin', 'elementary-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					$normal_targ => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Border::get_type(),
			[
				'label' => esc_html__( 'Border', 'elementary-addons' ),
				'name' => $prefix . '_border',
				'selector' => $normal_targ,
				'fields_options' => [
					'color' => [
						'dynamic' => [],
					],
				],
			]
		);

		$obj->add_control(
			$prefix . '_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					$normal_targ => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => $prefix . '_background',
				'types' => [ 'classic', 'gradient' ],
				'selector' => $normal_targ,
				'fields_options' => [
					'background' => [
						'default' => '',
					],
					'color' => [
						'dynamic' => [],
					],
					'color_b' => [
						'dynamic' => [],
					],
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => $prefix . '_shadow',
				'selector' => $normal_targ,
			]
		);

		$obj->end_controls_tab();


		$obj->start_controls_tab(
			$prefix . '_hover',
			[
				'label' => esc_html__( 'Hover', 'elementary-addons' ),
			]
		);

		$obj->add_control(
			$prefix . '_color_hover',
			[
				'label'  => esc_html__( 'Color', 'elementary-addons' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					$hover_targ => 'color: {{VALUE}}',
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__( 'Typography', 'elementary-addons' ),
				'name' => $prefix . '_typography_hover',
				'selector' => $hover_targ,
				'global' => [
					'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => $prefix . '_shadow_hover',
				'selector' => $hover_targ,
			]
		);



		$obj->add_responsive_control(
			$prefix . '_padding_hover',
			[
				'label' => esc_html__( 'Padding', 'elementary-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					$hover_targ => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
			]
		);

		$obj->add_responsive_control(
			$prefix . '_margin_hover',
			[
				'label' => esc_html__( 'Margin', 'elementary-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					$hover_targ => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Border::get_type(),
			[
				'label' => esc_html__( 'Border', 'elementary-addons' ),
				'name' => $prefix . '_border_hover',
				'selector' => $hover_targ,
				'fields_options' => [
					'color' => [
						'dynamic' => [],
					],
				],
			]
		);

		$obj->add_control(
			$prefix . '_radius_hover',
			[
				'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					$hover_targ => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => $prefix . '_background_hover',
				'types' => [ 'classic', 'gradient' ],
				'selector' => $hover_targ,
				'fields_options' => [
					'background' => [
						'default' => '',
					],
					'color' => [
						'dynamic' => [],
					],
					'color_b' => [
						'dynamic' => [],
					],
				],
			]
		);

		$obj->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => $prefix . '_shadow_hover',
				'selector' => $hover_targ,
			]
		);

		$obj->end_controls_tab();
		$obj->end_controls_tabs();

		$obj->add_control(
			$prefix . '_transition_time',
			[
				'label'   => esc_html__( 'Transition Time', 'elementary-addons' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 0.5,
				'step' => 0.1,
				'selectors' => [
					$normal_targ => 'transition:all {{VALUE}}s;',
				],
				// 'separator' => 'before',
			]
		);
	} // button3 Controls

	///////////////////////////////// BLOCK CONTROLS /////////////////////////////
	public static function get_block_style_controls( $obj, $prefix, $targets = array(), $excluded = array() ){

		$single_sel_targets = ( is_array( $targets ) && count( $targets ) > 1 ) ? implode( ', ', $targets ) : $targets[0];

		$obj->add_responsive_control(
      $prefix . '_padding',
      [
        'label' => esc_html__( 'Padding', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'default' => [
          'top' => 0,
          'bottom' => 0,
          'left' => 0,
          'right' => 0,
          'unit' => 'px',
        ],
        'selectors' => [
          $single_sel_targets => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

		if ( !in_array( 'margin', $excluded ) ) {
			$obj->add_responsive_control(
	      $prefix . '_margin',
	      [
	        'label' => esc_html__( 'Margin', 'elementary-addons' ),
	        'type' => Controls_Manager::DIMENSIONS,
	        'size_units' => [ 'px', 'em', '%' ],
	        'default' => [
	          'top' => 0,
	          'bottom' => 0,
	          'left' => 0,
	          'right' => 0,
	          'unit' => 'px',
	        ],
	        'selectors' => [
	          $single_sel_targets => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	        ],
	      ]
	    );
		}

    $obj->add_group_control(
      Group_Control_Border::get_type(),
      [
        'label' => esc_html__( 'Border', 'elementary-addons' ),
        'name' => $prefix . '_border',
        'selector' => $single_sel_targets,
        'fields_options' => [
          'color' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $obj->add_control(
      $prefix . '_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          $single_sel_targets => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};box-sizing:border-box;',
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => $prefix . '_background',
        'types' => [ 'classic', 'gradient' ],
        'selector' => $single_sel_targets,
        'fields_options' => [
          'background' => [
            'default' => '',
          ],
          'color' => [
            'dynamic' => [],
          ],
          'color_b' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => $prefix . '_box_shadow',
        'selector' => $single_sel_targets,
      ]
    );
	} // block controls

	///////////////////////////////// BLOCK TEXT CONTROLS /////////////////////////////
	public static function get_block_text_style_controls( $obj, $prefix, $targets = array(), $excluded = array() ){

		$single_sel_targets = ( is_array( $targets ) && count( $targets ) > 1 ) ? implode( ', ', $targets ) : $targets[0];

		$obj->add_control(
      $prefix . '_color',
      [
        'label'  => esc_html__( 'Color', 'elementary-addons' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          $single_sel_targets => 'color: {{VALUE}}',
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'label' => esc_html__( 'Typography', 'elementary-addons' ),
        'name' => $prefix . '_typography',
        'selector' => $single_sel_targets,
        'global' => [
          'default' => Global_Typography::TYPOGRAPHY_SECONDARY,
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => $prefix . '_text_shadow',
        'selector' => $single_sel_targets,
      ]
    );

		$obj->add_responsive_control(
      $prefix . '_padding',
      [
        'label' => esc_html__( 'Padding', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'default' => [
          'top' => 0,
          'bottom' => 0,
          'left' => 0,
          'right' => 0,
          'unit' => 'px',
        ],
        'selectors' => [
          $single_sel_targets => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

		if ( !in_array( 'margin', $excluded ) ) {
			$obj->add_responsive_control(
	      $prefix . '_margin',
	      [
	        'label' => esc_html__( 'Margin', 'elementary-addons' ),
	        'type' => Controls_Manager::DIMENSIONS,
	        'size_units' => [ 'px', 'em', '%' ],
	        'default' => [
	          'top' => 0,
	          'bottom' => 0,
	          'left' => 0,
	          'right' => 0,
	          'unit' => 'px',
	        ],
	        'selectors' => [
	          $single_sel_targets => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	        ],
	      ]
	    );
		}


    $obj->add_group_control(
      Group_Control_Border::get_type(),
      [
        'label' => esc_html__( 'Border', 'elementary-addons' ),
        'name' => $prefix . '_border',
        'selector' => $single_sel_targets,
        'fields_options' => [
          'color' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $obj->add_control(
      $prefix . '_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'elementary-addons' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          $single_sel_targets => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};box-sizing:border-box;',
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => $prefix . '_background',
        'types' => [ 'classic', 'gradient' ],
        'selector' => $single_sel_targets,
        'fields_options' => [
          'background' => [
            'default' => '',
          ],
          'color' => [
            'dynamic' => [],
          ],
          'color_b' => [
            'dynamic' => [],
          ],
        ],
      ]
    );

    $obj->add_group_control(
      Group_Control_Box_Shadow::get_type(),
      [
        'name' => $prefix . '_box_shadow',
        'selector' => $single_sel_targets,
      ]
    );
	} // block  text controls

} // class BEA_Controls_Groups
