<?php

namespace ElementaryAddons\Widgets;

use ElementaryAddons\EAFREE_Inline_JS;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Core\DynamicTags\Tag;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class EAFREE_Lottie extends Widget_Base{

  public function get_name(){
    return 'eafree_lottie';
  }

  public function get_title(){
    return esc_html__('Lottie Animation', 'elementary-addons');
  }

  public function get_icon(){
    return 'eafree-icon eafree-icon-lottie'; // eicon-site-logo
  }

  public function get_categories(){
    return ['eafree-widgets'];
  }

  public function get_group() {
    return ['posts'];
  }

  protected function register_controls(){

    $this->start_controls_section(
      'eafree_lottie_settings_general',
      [
        'label' => 'General',
      ]
    );

    $this->add_control(
      'eafree_lottie_refresh',
      [
        'type' => Controls_Manager::RAW_HTML,
        'raw' => '<div class="elementor-update-preview editor-wpr-preview-update"><button class="elementor-button elementor-button-success" onclick="elementor.reloadPreview();">Refresh</button>',
        'separator' => 'after'
      ]
    );

    $this->add_control(
      'eafree_lottie_source',
      [
        'label' => esc_html__( 'Lottie Source', 'elementary-addons' ),
        'type' => Controls_Manager::SELECT,
        'default' => 'json_file',
        'options' => [
          'json_file' => esc_html__( 'JSON File', 'elementary-addons' ),
          // 'dotlottie' => esc_html__( '.lottie File', 'elementary-addons' ),
          'url' => esc_html__( 'URL', 'elementary-addons' ),
        ],
      ]
    );

    $this->add_control(
      'eafree_lottie_json',
      [
        'label' => esc_html__( 'Upload JSON', 'elementary-addons' ),
        'type' => Controls_Manager::MEDIA,
        'media_type' => 'application/json',
        'frontend_available' => true,
        'condition' => [ 'eafree_lottie_source' => 'json_file' ],
      ]
    );

    // $this->add_control(
    //   'eafree_lottie_dotlottie',
    //   [
    //     'label' => esc_html__( 'Upload .lottie', 'elementary-addons' ),
    //     'type' => Controls_Manager::MEDIA,
    //     'media_type' => 'application/zip+lottie',
    //     'frontend_available' => true,
    //     'condition' => [ 'eafree_lottie_source' => 'dotlottie' ],
    //   ]
    // );

    $this->add_control(
      'eafree_lottie_url',
      [
        'label' => esc_html__( 'Lottie URL', 'elementary-addons' ),
        'type' => Controls_Manager::URL,
        'placeholder' => esc_html__( 'URL', 'elementary-addons' ),
        'frontend_available' => true,
        'dynamic' => [
          'active' => true,
        ],
        'condition' => [ 'eafree_lottie_source' => 'url' ],
      ]
    );

    $this->add_responsive_control(
      'eafree_lottie_align',
      [
        'label' => esc_html__( 'Alignment', 'elementary-addons' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          'left'    => [
            'title' => esc_html__( 'Left', 'elementary-addons' ),
            'icon' => 'eicon-text-align-left',
          ],
          'center' => [
            'title' => esc_html__( 'Center', 'elementary-addons' ),
            'icon' => 'eicon-text-align-center',
          ],
          'right' => [
            'title' => esc_html__( 'Right', 'elementary-addons' ),
            'icon' => 'eicon-text-align-right',
          ],
        ],
        'default' => 'center',
        'selectors' => [
          '{{WRAPPER}} .eafree_lottie' => 'text-align:{{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'eafree_lottie_autoplay',
      [
        'label' => esc_html__( 'Autoplay', 'elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'eafree_lottie_loop',
      [
        'label' => esc_html__( 'Play In Loop', 'elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'return_value' => 'yes',
        'default' => '',
        'frontend_available' => true,
      ]
    );

    $this->add_control(
      'eafree_lottie_speed',
      [
        'label' => esc_html__( 'Animation Speed', 'elementary-addons' ),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'unit' => 'px',
          'size' => 1,
        ],
        'range' => [
          'px' => [
            'min' => 0.1,
            'max' => 5,
            'step' => 0.1,
          ],
        ],
        'size_units' => [ 'px' ],
      ]
    );

    $this->add_control(
      'eafree_lottie_lazyload',
      [
        'label' => esc_html__( 'Lazy Loading', 'elementary-addons' ),
        'type' => Controls_Manager::SWITCHER,
        'return_value' => 'yes',
        'default' => '',
      ]
    );

    $this->end_controls_section();

    ////////////////////////// STYLE
    $this->start_controls_section(
      'eafree_lottie_style_general',
      [
        'label' => esc_html__( 'General', 'elementary-addons' ),
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_responsive_control(
      'eafree_lottie_width',
      [
        'label' => esc_html__( 'Width', 'elementary-addons' ),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 300,
          'unit' => 'px',
        ],
        'tablet_default' => [
          'size' => 200,
          'unit' => 'px',
        ],
        'mobile_default' => [
          'size' => 100,
          'unit' => 'px',
        ],
        'size_units' => [ '%', 'px', 'vw' ],
        'range' => [
          '%' => [
            'min' => 1,
            'max' => 100,
          ],
          'px' => [
            'min' => 1,
            'max' => 1000,
          ],
          'vw' => [
            'min' => 1,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .eafree_lottie lottie-player, {{WRAPPER}} .eafree_lottie .player_placeholder' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_responsive_control(
      'eafree_lottie_height',
      [
        'label' => esc_html__( 'Height', 'elementary-addons' ),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 300,
          'unit' => 'px',
        ],
        'tablet_default' => [
          'size' => 200,
          'unit' => 'px',
        ],
        'mobile_default' => [
          'size' => 100,
          'unit' => 'px',
        ],
        'size_units' => [ '%', 'px', 'vw' ],
        'range' => [
          '%' => [
            'min' => 1,
            'max' => 100,
          ],
          'px' => [
            'min' => 1,
            'max' => 1000,
          ],
          'vw' => [
            'min' => 1,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .eafree_lottie lottie-player' => 'height: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .eafree_lottie, {{WRAPPER}} .eafree_lottie .player_placeholder' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->end_controls_section();
  }//end register controls



  protected function render(){
    $settings = $this->get_settings_for_display();
    $id = $this->get_id();
    // $this->add_inline_editing_attributes('post_heading', 'basic');
    // $this->add_render_attribute(
    //   'eafree_post_title',
    //   [
    //     'class' => ['post-heading__post-heading'],
    //   ]
    // );
    if ( 'json_file' === $settings['eafree_lottie_source'] && ! empty( $settings['eafree_lottie_json']['url'] ) ) {
      $lottie_url = $settings['eafree_lottie_json']['url'];
    }
    elseif ( 'url' === $settings['eafree_lottie_source'] && ! empty( $settings['eafree_lottie_url']['url'] ) ) {
      $lottie_url = $settings['eafree_lottie_url']['url'];
    }
    else{
      $lottie_url = 'https://assets7.lottiefiles.com/private_files/lf30_cgfdhxgx.json';
    }

    $is_loop = ( 'yes' === $settings['eafree_lottie_loop'] ) ? 'loop ' : '';
    $autoplay = ( 'yes' === $settings['eafree_lottie_autoplay'] ) ? 'autoplay ' : '';
    $speed = $settings['eafree_lottie_speed']['size'];
    ?>


    <?php if( \Elementor\Plugin::$instance->editor->is_edit_mode() ): ?>
      <script type="text/javascript">
      jQuery(document).ready(function($){
        <?php
        EAFREE_Inline_JS::elementary_addons_is_in_viewport();
        EAFREE_Inline_JS::elementary_addons_lottie_js( '.eafree_lottie_' . $id );
        ?>
      });
      </script>
    <?php endif; ?>
    <div
    class="eafree_lottie eafree_lottie_<?php echo esc_attr( $id ); ?>"
    data-src="<?php echo esc_url( $lottie_url ); ?>"
    data-speed="<?php echo esc_attr( $speed ); ?>"
    data-loop="<?php echo esc_attr( $is_loop ); ?>"
    data-autoplay="<?php echo esc_attr( $autoplay ); ?>"
    data-is_lazyload="<?php echo esc_attr( $settings['eafree_lottie_lazyload'] ); ?>"
    >
    <?php if( \Elementor\Plugin::$instance->editor->is_edit_mode() || $settings['eafree_lottie_lazyload'] !== 'yes' ): ?>

        <lottie-player
        class="lottie_player"
        src="<?php echo esc_url( $lottie_url ); ?>"
        speed="<?php echo esc_attr( $speed ); ?>"
        <?php echo esc_attr( $is_loop ); ?>
        <?php echo esc_attr( $autoplay ); ?>
        >
        </lottie-player>
    <?php else: ?>
      <div class="player_placeholder">

      </div>
    <?php endif; ?>
  </div>
  <?php
  $GLOBALS['elementary_addons_lottie_count'] += 1;
}// end render
}
